#[non_exhaustive]pub struct Frame {
pub pixels: Vec<u8>,
pub width: u32,
pub height: u32,
pub delay_centiseconds: u16,
pub disposal: Disposal,
}Expand description
One decoded frame, with the animation metadata that came with it.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pixels: Vec<u8>The whole canvas after this frame is composited, as RGBA8.
width: u32Canvas width.
height: u32Canvas height.
delay_centiseconds: u16Delay before the next frame, in hundredths of a second.
disposal: DisposalHow this frame is disposed of before the next is drawn.